Discovered an issue?
====================

Want to talk with `@funilrys`_ about it? Contact `@funilrys on Keybase`_.

Want to make it public? Fill out a `new issue`_.

Don't want to fill out an issue on GitHub?
Let's discuss it on our `issues team`_ on Keybase.

Need help?
==========

Do you need help with the usage of PyFunceble? We can help!

Want to talk with `@funilrys`_ about it? Contact `@funilrys on Keybase`_.

Otherwise, let's discuss it on our `support team`_ on Keybase!

Need information?
=================

You can get information and discuss about PyFunceble on our 
`main Keybase team`_. @Funilrys (me) will do his best to keep it up-to-date 
with some information about the development and other news about PyFunceble.

If you need more information, the  `support team`_ or `issues team`_, is the 
place to ask!

.. _@funilrys: https://github.com/funilrys
.. _@funilrys on Keybase: https://keybase.io/funilrys
.. _new issue: https://github.com/funilrys/PyFunceble/issues/new/choose
.. _issues team: https://keybase.io/team/pyfunceble.issues
.. _support team: https://keybase.io/team/pyfunceble.support
.. _main Keybase team: https://keybase.io/team/pyfunceble

